/*
 * Zynaptic Reaction - An asynchronous programming framework for Java.
 * 
 * Copyright (c) 2009-2012, Zynaptic Limited. All rights reserved. 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 2 only, as published by
 * the Free Software Foundation. Zynaptic Limited designates this particular
 * file as subject to the "Classpath" exception as provided in the LICENSE
 * file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version 2
 * along with this work; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please visit www.zynaptic.com or contact reaction@zynaptic.com if you need
 * additional information or have any questions.
 */

package com.zynaptic.reaction.util;

/**
 * Provides a basic log service which prints all log messages generated by the
 * reactor to the console.
 * 
 * @author Chris Holgate
 */
public final class ReactorLogSystemOut implements ReactorLogTarget {

  /*
   * Implements ReactorLogTarget.log(...)
   */
  public final synchronized void log(int level, String message) {
    log(level, message, null);
  }

  /*
   * Implements ReactorLogTarget.log(...)
   */
  public final synchronized void log(int level, String message, Throwable exception) {
    switch (level) {
    case LOG_ERROR:
      System.out.println("ERROR   : " + message);
      break;
    case LOG_WARNING:
      System.out.println("WARNING : " + message);
      break;
    case LOG_INFO:
      System.out.println("INFO    : " + message);
      break;
    case LOG_DEBUG:
      System.out.println("DEBUG   : " + message);
      break;
    }
    if (exception != null) {
      System.out.print("THROWN  : ");
      exception.printStackTrace(System.out);
    }
  }
}